# This file contains global constants used by all files

# Set verbose to 0, 1, 2 to set the quantity of informations in the output.

verbose = 1

# Set verified_with_hikmot = TRUE if you want the program to use the hikmot algorithm

verify_with_hikmot = True

# Number of times the program hikmot ensured the hyperbolicity.
# ACHTUNG: serve? To be removed
# number_of_hikmot = 1

# Number of times the program tries to randomize a triangulation to look for
# a geometric solution. Set to zero if you want a rigorous non-random proof.

number_of_randomizes = 30

# If try_fillings == True the routine 'try_to_hyperbolize' tries to fill permanently some cusps.
# Filling permanently often give better solutions. Typically set to True.

try_permanent_fillings = True

# When there are many cusps (say n>10, this happens when we look at coverings)
# the routine that tries all permanent fillings checks all the subsets of n cusps
# to be filled and can take a lot of time.
# If the following flag is True, it checks only the maximum permanent fillings,
# where all cusps are filled except at most one (if closed).
# Note however that with find_exceptional_fillings we get better results with 'False'. 
#
#
# Therefore:
# If you use find_exceptional_fillings, set this flag to False (default)
# If you use search_geometric_solutions, set this flag to True

try_only_maximal_permanent_fillings = False

# The function positive_solution() returns True only if every tetrahedron shape
# has the imaginary part bigger than the constant 'min_imaginary'.
# We usually set it to 0.001

min_imaginary = 0.001

# We have re-written the Snappea functions that calculate the cusp shape and area (of a maximal section)
# in order to control numerical errors. With the following flags we can ask the program to use
# either Snappy's functions or ours. At least one flag need to be 'True'. 
# 1. If both flags are 'True', the program uses our functions but evaluate both, and prints 
#		the discrepancy between their results. This can be used as a sanity check for our functions. 
# 2. The proof is rigorous if 'use_our_functions' is True, regardless of 'use_SnapPea_functions'.

use_our_functions = True
use_SnapPea_functions = False

# Quotient the resulting candidate exceptional fillings by the action of the isometry group of N

quotient_by_isometries = True

# Prints homology of the exceptional manifolds

print_homologies = False

# Prints the candidate hyperbolic fillings

print_candidate_hyperbolic = True

# Completely ignores all the closed fillings whose first homology contains torsion.
# Usually set to False.
# (Useful if we are only interested in detecting S^3 or connected sums of S^2xS^1)

ignore_closed_manifolds_with_homology_torsion = False

# Write the slopes in latex

output_in_latex = False

