import snappy
import math
from math import sqrt, pi
import cmath
from cmath import log, exp
import copy

# constants.py contains the global constants used in all files

from constants import *

# functions.py contains the basic numerical functions used here

from functions import *

# exclude.py contains the list of slopes that are excluded from the analysis

from exclude import *

# manifold.py contains functions that use the manifold class

from manifold import *

# Write here the sub-fillings that you want to exclude. 
# The program will cancel any filling that contains any image of any 
# of these subfillings along the isometry group of the manifold.


do_exclude = False
calculate_all_orbits = False

										
# Here you must set the manifold N you want to investigate. 
# Some examples are listed below.

# N = snappy.Manifold('4_1')             #The figure-8 knot complement
# N = snappy.Manifold('Whitehead.tri')            #The Whitehead link complement
# N = snappy.Manifold('chain3.tri')      #The magic manifold (chain link with 3 components)
# N = snappy.Manifold('chain4.tri')      #The chain link with 4 components with vol = 2octahedra
# N = snappy.Manifold('chain5.tri')      #The chain link with 5 components
# N = snappy.Manifold('chain5_fill_m1.tri')      #The chain link with 5 components filled with -1
# N = snappy.Manifold('chain5_fill_m2.tri')      #The chain link with 5 components filled with -2
# N = snappy.Manifold('Borromean_rings.tri')		#The Borromean rings
N = snappy.Manifold('chain6.tri')      #The manifold chain6 with 6 components
# N = snappy.Manifold('chain6_fill_2.tri')      #The manifold chain6 with 6 components filled with 2
# N = snappy.Manifold('chain6_fill_2_1over2.tri')		#The manifold chain6 filled by 2,1/2 on two consecutive cusps
# N = snappy.Manifold('chain6_fill_2_o_m2.tri') 	#The manifold chain6 filled by 2, -2 on opposite cusps
# N = snappy.Manifold('chain6_fill_2_o_m1over2.tri') 	#The manifold chain6 filled by 2, -1/2 on opposite cusps
# N = snappy.Manifold('chain7.tri') # The chain link with 7 components
# N = snappy.Manifold('chain7_fill_1.tri') # The chain link with 7 components filled with 1
# N = snappy.Manifold('chain7_fill_m2.tri') # The chain link with 7 components filled with -2
# N = snappy.Manifold('chain6b.tri')

# The main program starts here

if verbose:
	print 'Manifold volume:'
	print N.volume()
	print 'Cusp shapes:'
	print N.cusp_info()

print 'Fillings to be investigated:'
print fillings
print 'Total:', len(fillings)

G = N.symmetry_group()
if verbose == 2: print 'symmetry group:', G
isometries = G.isometries()

# Quotient fillings up to isometries.
# Recall that every filling is transformed into the smallest lexicographic element
# in its orbit.

fillings_up_to_isometries = quotient_list_by_isometries(fillings, isometries)

# Print the list:

print 'Fillings up to isometries:'

if output_in_latex:
	print list_to_latex(fillings_up_to_isometries)
else:
	print fillings_up_to_isometries
print 'Total:', len(fillings_up_to_isometries)

# If do_exclude == True, then we filter the list obtained 
# by removing the orbits of the excluded fillings

if do_exclude == True:
	exclude_all = []

	# Construct the union of the orbits of all the excluded fillings

	for filling in exclude:
		orbit = get_orbit(filling, isometries)
		exclude_all = exclude_all + orbit

	# Filter the obtained fillings that do not contain any excluded filling

	filtered_fillings_up_to_isometries = []

	for filling in fillings_up_to_isometries:
		if list_contains(filling, exclude_all):
			print filling, 'da togliere'
		else:
			print filling
			filtered_fillings_up_to_isometries.append(filling)

	print 'Filtered after exclude:'

	if output_in_latex:
		print list_to_latex(filtered_fillings_up_to_isometries)
	else:
		print filtered_fillings_up_to_isometries
	print 'Total:', len(filtered_fillings_up_to_isometries)
	fillings_up_to_isometries = filtered_fillings_up_to_isometries[:]

# If calculate_all_orbits == True, construct a list containing
# all the orbits of the fillings in 'fillings_up_to_isometries'

if calculate_all_orbits == True:
	all_orbits_of_fillings = expand_list_by_isometries(fillings_up_to_isometries, isometries)
	print 'All the orbits of the fillings:'

	if output_in_latex:
		print list_to_latex(all_orbits_of_fillings)
	else:
		print all_orbits_of_fillings
#		for filling in all_orbits_of_fillings:
#			print filling
	print 'Total:', len(all_orbits_of_fillings)

